@@ -4,17 +4,24 @@
 #' This function allows you to geocode addresses and return the corresponding
 #' spatial object.
 #'
-#' The parameter `points_only` specifies whether the function results will be points (all Nominatim results are guaranteed to have at least point geometry) or possibly other spatial objects.
+#' The parameter `points_only` specifies whether the function results will be
+#' points (all Nominatim results are guaranteed to have at least point
+#' geometry) or possibly other spatial objects.
 #'
-#' Note that the type of geometry returned in case of `points_only = FALSE` will depend on the object being geocoded:
+#' Note that the type of geometry returned in case of `points_only = FALSE`
+#' will depend on the object being geocoded:
 #'
-#'   * administrative areas, major buildings and the like will be returned as polygons
+#'   * administrative areas, major buildings and the like will be
+#'     returned as polygons
 #'   * rivers, roads and their like as lines
 #'   * amenities may be points even in case of a `points_only = FALSE` call
 #'
-#' The function is vectorized, allowing for multiple addresses to be geocoded; in case of `points_only = FALSE`  multiple geometry types may be returned.
+#' The function is vectorized, allowing for multiple addresses to be geocoded;
+#' in case of `points_only = FALSE`  multiple geometry types may be returned.
 #'
-#' @param points_only Logical `TRUE/FALSE`. Whether to return only spatial points (`TRUE`, which is the default) or potentially other shapes as provided by the Nominatim API (`FALSE`).
+#' @param points_only Logical `TRUE/FALSE`. Whether to return only spatial
+#' points (`TRUE`, which is the default) or potentially other shapes as
+#' provided by the Nominatim API (`FALSE`).
 #'
 #' @inheritParams geo_lite
 #'
@@ -89,10 +96,6 @@ geo_lite_sf <- function(address,
   all_res <- NULL
 
   for (i in seq_len(length(address))) {
-    if (i > 1) {
-      Sys.sleep(1)
-    }
-
     res_single <- geo_lite_sf_single(
       address = address[i],
       limit,
@@ -152,21 +155,15 @@ geo_lite_sf_single <- function(address,
 
   json <- tempfile(fileext = ".geojson")
 
-  # nocov start
-  res <- tryCatch(
-    download.file(url, json, mode = "wb", quiet = isFALSE(verbose)),
-    warning = function(e) {
-      return(NULL)
-    },
-    error = function(e) {
-      return(NULL)
-    }
-  )
+  res <- api_call(url, json, quiet = isFALSE(verbose))
 
-  if (is.null(res)) {
+
+  # nocov start
+
+  if (isFALSE(res)) {
     message(url, " not reachable.")
     result_out <- data.frame(query = address)
-    return(result_out)
+    return(invisible(result_out))
   }
   # nocov end
 
@@ -180,7 +177,7 @@ geo_lite_sf_single <- function(address,
   if (length(names(sfobj)) == 1) {
     message("No results for query ", address)
     result_out <- data.frame(query = address)
-    return(result_out)
+    return(invisible(result_out))
   }
 
   # Prepare output
