@@ -103,10 +103,6 @@ reverse_geo_lite <- function(lat,
   all_res <- NULL
 
   for (i in seq_len(length(long_cap))) {
-    if (i > 1) {
-      Sys.sleep(1)
-    }
-
     res_single <- reverse_geo_lite_single(
       lat_cap[i],
       long_cap[i],
@@ -163,22 +159,15 @@ reverse_geo_lite_single <- function(lat_cap,
 
   json <- tempfile(fileext = ".json")
 
-  # nocov start
-  res <- tryCatch(
-    download.file(url, json, mode = "wb", quiet = isFALSE(verbose)),
-    warning = function(e) {
-      return(NULL)
-    },
-    error = function(e) {
-      return(NULL)
-    }
-  )
+  res <- api_call(url, json, quiet = isFALSE(verbose))
 
-  if (is.null(res)) {
+
+  # nocov start
+  if (isFALSE(res)) {
     message(url, " not reachable.")
     result_out <- tibble::tibble(ad = NA)
     names(result_out) <- address
-    return(result_out)
+    return(invisible(result_out))
   }
 
   # nocov end
@@ -192,7 +181,7 @@ reverse_geo_lite_single <- function(lat_cap,
     )
     result_out <- tibble::tibble(ad = NA)
     names(result_out) <- address
-    return(result_out)
+    return(invisible(result_out))
   }
 
 
