@@ -1,6 +1,7 @@
 test_that("Returning empty query", {
   expect_message(geo_lite("xbzbzbzoa aiaia"))
 
+  skip_on_cran()
   skip_if_api_server()
 
   obj <- geo_lite("xbzbzbzoa aiaia")
@@ -11,17 +12,23 @@ test_that("Returning empty query", {
 })
 
 test_that("Data format", {
+  skip_on_cran()
   skip_if_api_server()
   skip_if_offline()
+
+
   expect_true(is.data.frame(geo_lite("Madrid")))
-  expect_false(inherits(geo_lite("Madrid"), "sf")) # this is _not_ a _sf function
+  expect_false(inherits(geo_lite("Madrid"), "sf"))
+  # this is _not_ a _sf function
 })
 
 
 test_that("Checking query", {
+  skip_on_cran()
   skip_if_api_server()
   skip_if_offline()
 
+
   expect_equal(ncol(geo_lite(c("Madrid", "Barcelona"))), 4)
   expect_gt(ncol(geo_lite("Madrid", full_results = TRUE)), 4)
   expect_gt(nrow(geo_lite("Madrid",
